@@ -1,10 +1,11 @@
-from cekit.descriptor import Image
-from cekit.descriptor.image import get_image_schema
 import copy
 
+from cekit.descriptor import Image
+from cekit.descriptor.image import get_image_schema
+
 overrides_schema = get_image_schema()
-overrides_schema['map']['name'] = {'type': 'str'}
-overrides_schema['map']['version'] = {'type': 'text'}
+overrides_schema["map"]["name"] = {"type": "str"}
+overrides_schema["map"]["version"] = {"type": "text"}
 
 
 class Overrides(Image):
