@@ -2,9 +2,10 @@ import logging
 import os
 
 from cekit.builder import Command
-from cekit.generator.base import Generator
+from cekit.generator.behave import BehaveGenerator
 from cekit.test.behave_runner import BehaveTestRunner
 from cekit.test.collector import BehaveTestCollector
+from cekit.version import schema_version
 
 LOGGER = logging.getLogger("cekit")
 
@@ -28,7 +29,7 @@ class BehaveTester(Command):
         self.generator = None
 
     def prepare(self):
-        self.generator = Generator(
+        self.generator = BehaveGenerator(
             self.params.descriptor, self.params.target, self.params.overrides
         )
 
@@ -38,9 +39,13 @@ class BehaveTester(Command):
 
         self.generator.init()
 
-        # TODO: investigate if we can improve handling different schema versions
+        self.generator.generate()
+
+        # The branch to clone is determined by the schema_version in the descriptor prefixed with `v`
+        # It defaults to the CEKIt current schema_version.
         self.collected = self.test_collector.collect(
-            self.generator.image.get("schema_version"), self.params.steps_url
+            self.generator.image.get("schema_version", schema_version),
+            self.params.steps_url,
         )
 
         if self.collected:
